Parallel Animation

- Home
- Tutorials
  - Basic Animations
  - Parallel Animations
  - Sequence Animations
  - Timing Dictionary
  - Timing Functions
- References
- About

Web Animations Tutorial

Web animations is to have a flash or GIF animation intergrated onto the web page. Normal web animations still require the use of plugins such as Java Applets, Shockwave, Adobe Flash. In this tutorial, we will be showing you how to create animations using javascript without the need of installing plugins.

Parallel Animation Group

There certainly are times when you want to group items together such that they have the same features and effects. There are 2 types of groupings: parallel and sequential. In this section you will learn about parallel groups and what kind of feature does it have to help you write less code.

Just as what the name of the group means, all the children being grouped in a parallel group will run in parallel, that is they will start together and of course they will end at different time depends on their durations.

The following is the interface for creating a parallel animation group.

`new AnimationGroup([children], {timing/timing dictionary});`

Note that both children and timing are nullable (i.e. you can leave children as [] if you don't want to specify a child). Though only timing is optional

- Parallel Animation Group
- Basic Info
- Exercise 1
- Exercise 2
- Exercise 3